@@ -1,5 +1,15 @@
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # Standard library imports.
-from traits.testing.unittest_tools import unittest
+import unittest
 
 # Local imports.
 from traits.util.camel_case import camel_case_to_python, camel_case_to_words
@@ -49,7 +59,3 @@ class CamelCaseTestCase(unittest.TestCase):
         """ Does CamelCase -> words work?
         """
         self.assertEqual(camel_case_to_words("FooBarBaz"), "Foo Bar Baz")
-
-
-if __name__ == "__main__":
-    unittest.main()
